@@ -655,8 +655,9 @@ function whp_api_call($serverdata, $method, $endpoint, $data = null) {
         'protocol' => $protocol,
         'endpoint' => $endpoint,
         'method' => $method,
-        'api_key_set' => !empty($apiKey),
-        'api_secret_set' => !empty($apiSecret)
+        'api_key' => $apiKey,
+        'api_secret' => substr($apiSecret, 0, 10) . '...',
+        'full_url' => $url
     ), 'Starting API call');
     
     if (empty($apiKey) || empty($apiSecret)) {
@@ -684,10 +685,11 @@ function whp_api_call($serverdata, $method, $endpoint, $data = null) {
     ));
     
     // Set authentication headers
+    // Note: Headers must match exact case that the server expects
     curl_setopt($ch, CURLOPT_HTTPHEADER, array(
         'Content-Type: application/json',
-        'X-API-Key: ' . $apiKey,
-        'X-API-Secret: ' . $apiSecret,
+        'X-Api-Key: ' . $apiKey,
+        'X-Api-Secret: ' . $apiSecret,
     ));
     
     // Set method-specific options
